@@ -16,4 +16,4 @@ def GetMedia(search: str, baseUrl: str) -> AniListMedia:
     try:
         return ani_list_media_from_dict(r)
     except json.JSONDecodeError:
-        raise AniListException("{]".format(ani_list_error_from_dict(r)))
+        raise AniListException("{}".format(ani_list_error_from_dict(r)))
