@@ -2,6 +2,8 @@
 # public domain. For more information, please refer to <http://unlicense.org/>
 
 
+from anilistWrapPY.Airing.request import GetAiring
+from anilistWrapPY.Manga.request import GetManga
 from anilistWrapPY.Anime.request import GetAnime
 from anilistWrapPY.Character.request import GetCharacter
 from anilistWrapPY.Media.request import GetMedia
@@ -19,3 +21,9 @@ class aniWrapPYClient:
 
     def Character(self, query: str):
         return GetCharacter(search=query, baseUrl=self.baseUrl)
+    
+    def Manga(self, query: str):
+        return GetManga(search=query, baseUrl=self.baseUrl)
+    
+    def Airing(self, query: str):
+        return GetAiring(search=query, baseUrl=self.baseUrl)
